smartcard.CardType.ATRCardType

# ``smartcard`.`CardType`.`ATRCardType``

class documentation

`class ATRCardType(CardType):`

View In Hierarchy

The ATRCardType defines a card from an ATR and a mask.

Method | `__init__` | ATRCardType constructor.
Method | `matches` | Returns true if the atr matches the masked CardType atr.
Instance Variable | `atr` | Undocumented
Instance Variable | `mask` | Undocumented
Instance Variable | `maskedatr` | Undocumented

def __init__(self, atr, mask=None):
overrides `smartcard.CardType.CardType.__init__`

ATRCardType constructor.

Parameters
atr | the ATR of the CardType
mask | an optional mask to be applied to the ATR for `CardType` matching default is None

def matches(self, atr, reader=None):
overrides `smartcard.CardType.CardType.matches`

Returns true if the atr matches the masked CardType atr.

Parameters
atr | the atr to chek for matching
reader | the reader (optional); default is None When atr is compared to the CardType ATR, matches returns true if and only if CardType.atr & CardType.mask = atr & CardType.mask, where & is the bitwise logical AND.

atr =

Undocumented

mask =

Undocumented

maskedatr =

Undocumented